diff --git a/core/modules/tracker/src/Tests/TrackerTest.php b/core/modules/tracker/src/Tests/TrackerTest.php
index 354e842..70602f8 100644
--- a/core/modules/tracker/src/Tests/TrackerTest.php
+++ b/core/modules/tracker/src/Tests/TrackerTest.php
@@ -36,7 +36,7 @@ class TrackerTest extends WebTestBase {
    *
    * @var object
    */
-  protected $other_user;
+  protected $otherUser;
 
   protected function setUp() {
     parent::setUp();
@@ -45,7 +45,7 @@ protected function setUp() {
 
     $permissions = array('access comments', 'create page content', 'post comments', 'skip comment approval');
     $this->user = $this->drupalCreateUser($permissions);
-    $this->other_user = $this->drupalCreateUser($permissions);
+    $this->otherUser = $this->drupalCreateUser($permissions);
     $this->container->get('comment.manager')->addDefaultField('node', 'page');
   }
 
@@ -93,12 +93,12 @@ function testTrackerUser() {
     ));
     $other_published_no_comment = $this->drupalCreateNode(array(
       'title' => $this->randomMachineName(8),
-      'uid' => $this->other_user->id(),
+      'uid' => $this->otherUser->id(),
       'status' => 1,
     ));
     $other_published_my_comment = $this->drupalCreateNode(array(
       'title' => $this->randomMachineName(8),
-      'uid' => $this->other_user->id(),
+      'uid' => $this->otherUser->id(),
       'status' => 1,
     ));
     $comment = array(
@@ -119,8 +119,8 @@ function testTrackerUser() {
     $this->assertTitle(t('@name | @site', array('@name' => $this->user->getUsername(), '@site' => \Drupal::config('system.site')->get('name'))), 'The user tracker page has the correct page title.');
 
     // Verify that unpublished comments are removed from the tracker.
-    $admin_user = $this->drupalCreateUser(array('post comments', 'administer comments', 'access user profiles'));
-    $this->drupalLogin($admin_user);
+    $adminUser = $this->drupalCreateUser(array('post comments', 'administer comments', 'access user profiles'));
+    $this->drupalLogin($adminUser);
     $this->drupalPostForm('comment/1/edit', array('status' => CommentInterface::NOT_PUBLISHED), t('Save'));
     $this->drupalGet('user/' . $this->user->id() . '/activity');
     $this->assertNoText($other_published_my_comment->label(), 'Unpublished comments are not counted on the tracker listing.');
@@ -153,7 +153,7 @@ function testTrackerNewNodes() {
     $this->drupalGet('activity');
     $this->assertNoPattern('/' . $title . '.*new/', 'Visited nodes are not flagged as new.');
 
-    $this->drupalLogin($this->other_user);
+    $this->drupalLogin($this->otherUser);
     $this->drupalGet('activity');
     $this->assertPattern('/' . $title . '.*new/', 'For another user, new nodes are flagged as such in the tracker listing.');
 
@@ -196,12 +196,12 @@ function testTrackerNewComments() {
       ),
     ));
 
-    $this->drupalLogin($this->other_user);
+    $this->drupalLogin($this->otherUser);
     $this->drupalGet('activity');
     $this->assertText('1 new', 'New comments are counted on the tracker listing pages.');
     $this->drupalGet('node/' . $node->id());
 
     // Add another comment as other_user.
     $comment = array(
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
@@ -231,8 +231,8 @@ function testTrackerOrderingNewComments() {
       'title' => $this->randomMachineName(8),
     ));
 
-    // Now get other_user to track these pieces of content.
-    $this->drupalLogin($this->other_user);
+    // Now get otherUser to track these pieces of content.
+    $this->drupalLogin($this->otherUser);
 
     // Add a comment to the first page.
     $comment = array(
@@ -252,7 +252,7 @@ function testTrackerOrderingNewComments() {
     );
     $this->drupalPostForm('comment/reply/node/' . $node_two->id() . '/comment', $comment, t('Save'));
 
     // We should at this point have in our tracker for other_user:
     // 1. node_two
     // 2. node_one
     // Because that's the reverse order of the posted comments.
@@ -272,9 +272,9 @@ function testTrackerOrderingNewComments() {
     );
     $this->drupalPostForm('comment/reply/node/' . $node_one->id() . '/comment', $comment, t('Save'));
 
-    // Switch back to the other_user and assert that the order has swapped.
-    $this->drupalLogin($this->other_user);
-    $this->drupalGet('user/' . $this->other_user->id() . '/activity');
+    // Switch back to the otherUser and assert that the order has swapped.
+    $this->drupalLogin($this->otherUser);
+    $this->drupalGet('user/' . $this->otherUser->id() . '/activity');
     // This is a cheeky way of asserting that the nodes are in the right order
     // on the tracker page.
     // It's almost certainly too brittle.
@@ -300,7 +300,7 @@ function testTrackerCronIndexing() {
     }
 
     // Add a comment to the last node as other user.
-    $this->drupalLogin($this->other_user);
+    $this->drupalLogin($this->otherUser);
     $comment = array(
       'subject[0][value]' => $this->randomMachineName(),
       'comment_body[0][value]' => $this->randomMachineName(20),
@@ -344,8 +344,8 @@ function testTrackerCronIndexing() {
    */
   function testTrackerAdminUnpublish() {
     \Drupal::service('module_installer')->install(array('views'));
-    $admin_user = $this->drupalCreateUser(array('access content overview', 'administer nodes', 'bypass node access'));
-    $this->drupalLogin($admin_user);
+    $adminUser = $this->drupalCreateUser(array('access content overview', 'administer nodes', 'bypass node access'));
+    $this->drupalLogin($adminUser);
 
     $node = $this->drupalCreateNode(array(
       'title' => $this->randomMachineName(),
@@ -196,12 +196,12 @@ function testTrackerNewComments() {
     $this->drupalGet('node/' . $node->id());
 
-    // Add another comment as other_user.
+    // Add another comment as otherUser.
     $comment = array(
       'subject[0][value]' => $this->randomMachineName(),
@@ -252,7 +252,7 @@ function testTrackerOrderingNewComments() {
     $this->drupalPostForm('comment/reply/node/' . $node_two->id() . '/comment', $comment, t('Save'));
 
-    // We should at this point have in our tracker for other_user:
+    // We should at this point have in our tracker for otherUser:
     // 1. node_two
     // 2. node_one
